@@ -8,6 +8,8 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_apigatewayv2._jsii
+import aws_cdk.aws_apigatewayv2_integrations._jsii
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_cloudfront_origins._jsii
 import aws_cdk.aws_iam._jsii
@@ -22,9 +24,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-cloudfront-plus",
-    "0.2.6",
+    "0.3.9",
     __name__[0:-6],
-    "cdk-cloudfront-plus@0.2.6.jsii.tgz",
+    "cdk-cloudfront-plus@0.3.9.jsii.tgz",
 )
 
 __all__ = [
